jaclearn.dataflow.utils
=======================

.. automodule:: jaclearn.dataflow.utils

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DataFlowMixer
      MapDataFlow
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cycle
      cycle_n
      ssmap
   
   

   
   
   








.. rubric:: Class DataFlowMixer
.. autoclass:: DataFlowMixer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MapDataFlow
.. autoclass:: MapDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: cycle

.. autofunction:: cycle_n

.. autofunction:: ssmap


